==> nsepythonserver-1.4.tar.gz: nsepythonserver-1.4/README.md <==
<p align="left">
  <a href="https://aeron7.github.io/nsepython/" target="_blank">
    <img width="300" src="https://github.com/aeron7/nsepython/blob/master/nsepython.png" alt="logo">
  </a>
</p>

#### NSEPython is a Python library to get publicly available data on the current [NSEIndia](https://nseindia.com) and [NIFTY Indices](https://www.niftyindices.com/) site by communicating with their REST APIs.

<p align="left">
  <a href="https://unofficed.com/nse-python/documentation/" target="_blank">
    <img width="200" src="https://github.com/aeron7/nsepython/blob/master/button_read-the-documentation.png" alt="logo">
  </a>
</p>

For Support and Beta Functions - [https://forum.unofficed.com/t/nsepython-documentation/376/107](https://forum.unofficed.com/t/nsepython-documentation/376/107)

## Installation

Use the package manager [pip](https://pypi.org/project/nsepython/) to install nsepython.

```bash
pip install nsepython
```
## Cross Library Migration
All the functions of the two famous packages NsepY and NSETools are also migrated here with same function name. <br/>
They were both unmaintained since long time.

## Advanced Usecases
[Calculate any Option Greek using Black Scholes Formula in Python](https://unofficed.com/black-scholes-formula-in-python/)

[ How to find the beta of Indian stocks using Python?](https://unofficed.com/how-to-find-the-beta-of-indian-stocks-using-python/)

[How to get Historical PE, PB and Dividend Ratio of any index using Python](https://unofficed.com/nse-python/documentation/nsepy/#index_pe_pb_div)

## Contributing
For Discussion and Improving this Code, Join - https://www.unofficed.com/chat/

==> nsepythonserver-1.7.tar.gz: nsepythonserver-1.7/README.md <==
<p align="left">
  <a href="https://aeron7.github.io/nsepython/" target="_blank">
    <img width="300" src="https://raw.githubusercontent.com/aeron7/nsepython/master/nsepython.png" alt="logo">
  </a>
</p>

#### NSEPython is a Python library to get publicly available data on the current [NSEIndia](https://nseindia.com) and [NIFTY Indices](https://www.niftyindices.com/) site by communicating with their REST APIs.

<p align="left">
  <a href="https://unofficed.com/nse-python/documentation/" target="_blank">
    <img width="200" src="https://raw.githubusercontent.com/aeron7/nsepython/master/button_read-the-documentation.png" alt="logo">
  </a>
</p>

For Support and Beta Functions - [https://forum.unofficed.com/t/nsepython-documentation/376/107](https://forum.unofficed.com/t/nsepython-documentation/376/107)

## Installation

Use the package manager [pip](https://pypi.org/project/nsepython/) to install nsepython.

```bash
pip install nsepythonserver
```
## Cross Library Migration
All the functions of the two famous packages NsepY and NSETools are also migrated here with same function name. <br/>
They were both unmaintained since long time.

## Advanced Usecases
[Calculate any Option Greek using Black Scholes Formula in Python](https://unofficed.com/black-scholes-formula-in-python/)

[ How to find the beta of Indian stocks using Python?](https://unofficed.com/how-to-find-the-beta-of-indian-stocks-using-python/)

[How to get Historical PE, PB and Dividend Ratio of any index using Python](https://unofficed.com/nse-python/documentation/nsepy/#index_pe_pb_div)

## Contributing
For Discussion and Improving this Code, Join - https://www.unofficed.com/chat/
